## easycalculate 2
<p>A package for calculate Math problem contain easy calculation and easy linear algebra problem, in the future author will add functions to solve easy geometry problems.</p>
<ul>
<li>Written by JinXinxi</li>
<li>Written with Python</li>
<li>Latest Version: 2024-3-29 2.0.0</li>
</ul>

## Brief overview:
Sum(): Sum function
Subtract(): Subtract function
Multiply(): quadrature function
Divide(): a quotient function that gives a judgment on whether to divide by integers, 0: not divide by integers; 1: Dividing by whole
Sqare(): Find the root of the power, the y-th power of x
Square_ Root(): Open root function
Invert(): Find the inverse ordinal number
Determinant(): Find the value of the number of rows and columns
Cofactor(): finding algebraic cofactors
matrix_show(): Format the output matrix by obtaining the input list, number of rows or columns, and by row or column.
cube_volume(): -> function's explanation
circle_square(): -> function's explanation
spherical_volume(): -> function's explanation
cuboid_volume(): -> function's explanation

## Improving
I improve the "matrix_show" module this time. It can auto adapt the shape of input data by users. It means it can transform input data from other type to list actively.

## Question
If you have any questions or problems, you can send me emails or submit to issue in my homepage.